@@ -68,6 +68,6 @@ pub enum PredicateType {
 
 impl std::fmt::Display for PredicateType {
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
-        write!(f, "{}", format!("{:?}", self))
+        write!(f, "{:?}", self)
     }
 }
